@@ -1,47 +1,48 @@
-from typing import Any, Dict, Union
-
 import astropy.units as u
 from astropy.units import Quantity
 
-from zodipy._labels import Label
+from ._component_label import ComponentLabel
 
 
-delta_K98 = 0.46686259861486573
-T_0_K98 = 286 * u.K
+T_0_DIRBE = 286  # K
+DELTA_DIRBE = 0.46686259861486573
 
-SPECTRUM_PLANCK = Quantity([100.0, 143.0, 217.0, 353.0, 545.0, 857.0], unit=u.GHz)
-SPECTRUM_DIRBE = Quantity([1.25, 2.2, 3.5, 4.9, 12, 25, 60, 100, 140, 240], unit=u.micron)
+SPECTRUM_PLANCK = Quantity([100.0, 143.0, 217.0, 353.0, 545.0, 857.0], u.GHz)
+SPECTRUM_DIRBE = Quantity([1.25, 2.2, 3.5, 4.9, 12, 25, 60, 100, 140, 240], u.micron)
 
-EMISSIVITY_PLANCK_13: Dict[Union[str, Label], Any] = {
-    Label.CLOUD: (0.003, -0.014, 0.031, 0.168, 0.223, 0.301),
-    Label.BAND1: (1.129, 1.463, 2.024, 2.035, 2.235, 1.777),
-    Label.BAND2: (0.674, 0.530, 0.338, 0.436, 0.718, 0.716),
-    Label.BAND3: (1.106, 1.794, 2.507, 2.400, 3.193, 2.870),
-    Label.RING: (0.163, -0.252, -0.185, -0.211, 0.591, 0.578),
-    Label.FEATURE: (0.252, -0.002, 0.243, 0.676, -0.182, 0.423),
-    "spectrum": SPECTRUM_PLANCK,
+EMISSIVITY_PLANCK_13 = {
+    ComponentLabel.CLOUD: (0.003, -0.014, 0.031, 0.168, 0.223, 0.301),
+    ComponentLabel.BAND1: (1.129, 1.463, 2.024, 2.035, 2.235, 1.777),
+    ComponentLabel.BAND2: (0.674, 0.530, 0.338, 0.436, 0.718, 0.716),
+    ComponentLabel.BAND3: (1.106, 1.794, 2.507, 2.400, 3.193, 2.870),
+    ComponentLabel.RING: (0.163, -0.252, -0.185, -0.211, 0.591, 0.578),
+    ComponentLabel.FEATURE: (0.252, -0.002, 0.243, 0.676, -0.182, 0.423),
 }
 
-EMISSIVITY_PLANCK_15: Dict[Union[str, Label], Any] = {
-    Label.CLOUD: (0.012, 0.022, 0.051, 0.106, 0.167, 0.256),
-    Label.BAND1: (1.02, 1.23, 1.30, 1.58, 1.74, 2.06),
-    Label.BAND2: (0.08, 0.15, 0.15, 0.39, 0.54, 0.85),
-    Label.BAND3: (0.72, 1.16, 1.27, 1.88, 2.54, 3.37),
-    "spectrum": SPECTRUM_PLANCK,
+EMISSIVITY_PLANCK_15 = {
+    ComponentLabel.CLOUD: (0.012, 0.022, 0.051, 0.106, 0.167, 0.256),
+    ComponentLabel.BAND1: (1.02, 1.23, 1.30, 1.58, 1.74, 2.06),
+    ComponentLabel.BAND2: (0.08, 0.15, 0.15, 0.39, 0.54, 0.85),
+    ComponentLabel.BAND3: (0.72, 1.16, 1.27, 1.88, 2.54, 3.37),
 }
 
 
-EMISSIVITY_PLANCK_18: Dict[Union[str, Label], Any] = {
-    Label.CLOUD: (0.018, 0.020, 0.042, 0.082, 0.179, 0.304),
-    Label.BAND1: (0.54, 1.00, 1.11, 1.52, 1.47, 1.58),
-    Label.BAND2: (0.07, 0.17, 0.21, 0.35, 0.49, 0.70),
-    Label.BAND3: (0.19, 0.84, 1.12, 1.77, 1.84, 2.11),
-    "spectrum": SPECTRUM_PLANCK,
+EMISSIVITY_PLANCK_18 = {
+    ComponentLabel.CLOUD: (0.018, 0.020, 0.042, 0.082, 0.179, 0.304),
+    ComponentLabel.BAND1: (0.54, 1.00, 1.11, 1.52, 1.47, 1.58),
+    ComponentLabel.BAND2: (0.07, 0.17, 0.21, 0.35, 0.49, 0.70),
+    ComponentLabel.BAND3: (0.19, 0.84, 1.12, 1.77, 1.84, 2.11),
 }
 
+EMISSIVITY_ODEGARD = {
+    ComponentLabel.CLOUD: (0.014, 0.023, 0.063, 0.132, 0.210, 0.285),
+    ComponentLabel.BAND1: (1.25, 1.39, 1.85, 2.41, 2.81, 3.23),
+    ComponentLabel.BAND2: (0.15, 0.22, 0.40, 0.80, 1.11, 1.58),
+    ComponentLabel.BAND3: (0.50, 0.89, 1.22, 1.96, 2.81, 3.60),
+}
 
-EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
-    Label.CLOUD: (
+EMISSIVITY_DIRBE = {
+    ComponentLabel.CLOUD: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -53,7 +54,7 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         0.67694205881047387,
         0.51912085401950736,
     ),
-    Label.BAND1: (
+    ComponentLabel.BAND1: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -65,7 +66,7 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         1.1317240279481993,
         1.3996145963796358,
     ),
-    Label.BAND2: (
+    ComponentLabel.BAND2: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -77,7 +78,7 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         1.1317240279481993,
         1.3996145963796358,
     ),
-    Label.BAND3: (
+    ComponentLabel.BAND3: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -89,7 +90,7 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         1.1317240279481993,
         1.3996145963796358,
     ),
-    Label.RING: (
+    ComponentLabel.RING: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -101,7 +102,7 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         1.1515825707787077,
         0.85763800994217443,
     ),
-    Label.FEATURE: (
+    ComponentLabel.FEATURE: (
         1.0,
         1.0,
         1.6598924040649741,
@@ -113,11 +114,10 @@ EMISSIVITY_DIRBE: Dict[Union[str, Label], Any] = {
         1.1515825707787077,
         0.85763800994217443,
     ),
-    "spectrum": SPECTRUM_DIRBE,
 }
 
-ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
-    Label.CLOUD: (
+ALBEDO_DIRBE = {
+    ComponentLabel.CLOUD: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -129,7 +129,7 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    Label.BAND1: (
+    ComponentLabel.BAND1: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -141,7 +141,7 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    Label.BAND2: (
+    ComponentLabel.BAND2: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -153,7 +153,7 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    Label.BAND3: (
+    ComponentLabel.BAND3: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -165,7 +165,7 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    Label.RING: (
+    ComponentLabel.RING: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -177,7 +177,7 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    Label.FEATURE: (
+    ComponentLabel.FEATURE: (
         0.20411939612669797,
         0.25521132892052301,
         0.21043660481632315,
@@ -189,12 +189,23 @@ ALBEDO_DIRBE: Dict[Union[str, Label], Any] = {
         0.0,
         0.0,
     ),
-    "spectrum": SPECTRUM_DIRBE,
 }
 
-PHASE_DIRBE: Dict[str, Any] = {
-    "C0": Quantity([-0.942, -0.527, -0.431, 0, 0, 0, 0, 0, 0, 0], unit=1/u.sr),
-    "C1": Quantity([0.121, 0.187, -0.431, 0, 0, 0, 0, 0, 0, 0], unit=1/u.rad/u.sr),
-    "C2": Quantity([-0.165, 0.187, -0.431, 0, 0, 0, 0, 0, 0, 0], unit=1/u.rad),
-    "spectrum": SPECTRUM_DIRBE,
-}
+PHASE_FUNCTION_DIRBE = [
+    (-0.94209999, -0.52670002, -0.4312, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0),
+    (0.1214, 0.18719999, 0.1715, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0),
+    (-0.1648, -0.59829998, -0.63330001, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0),
+]
+
+SOLAR_IRRADIANCE_DIRBE = [
+    2.3405606e8,
+    1.2309874e8,
+    64292872,
+    35733824,
+    5763843.0,
+    1327989.4,
+    230553.73,
+    82999.336,
+    42346.605,
+    14409.608,
+] * (u.MJy / u.sr)
